//                              -*- Mode: C++ -*- 
// 
// uC++ Version 5.3.0, Copyright (C) Peter A. Buhr 1994
// 
// NBStream.cc -- 
// 
// Author           : Peter A. Buhr
// Created On       : Wed Apr 28 13:23:14 1993
// Last Modified By : Peter A. Buhr
// Last Modified On : Sun Jul 31 19:00:44 2005
// Update Count     : 21
// 

#include <uC++.h>
#include <iostream>
using std::cin;
using std::cerr;

int d = 1;						// shared by reader and writer

_Task Reader {
    void main() {
	for ( ;; ) {
	    cin >> d;					// read number from stdin
	  if ( cin.eof() ) break;
	} // for
    } // Reader::main
}; // Reader

_Task Writer {
    void main() {
	for ( int i = 0;; i += 1 ) {
	  if ( cin.eof() ) break;
	    if ( i % 100 == 0 ) {			// don't print too much
		cerr << d;				// write number to stderr (no buffering)
	    } // if					// if cout is used, it must be flushed with endl
	    yield( 1 );
	} // for
    } // Writer::main
}; // Writer

void uMain::main() {
    Reader r;
    Writer w;
} // uMain::main

// Local Variables: //
// compile-command: "u++ NBStream.cc" //
// End: //
